#!/bin/sh                                                    

cd /motadata/motadata
. ./agent-env

nohup /motadata/motadata/jdk/bin/java $JAVA_OPTS -cp Motadata.jar:/motadata/motadata/lib/* com.mindarray.Bootstrap AGENT & echo $!
